@@ -59,6 +59,15 @@ class Enum:
         except IndexError:
             pass
 
+    @staticmethod
+    def _upd_enum_def(enums, data):
+        members = enums[data['enum_id']]
+        # swap index
+        idx = data['index']
+        tmp = members[idx]
+        members[idx] = members[0]
+        members[0] = tmp
+
     @staticmethod
     def _upd_enum_mod(enums, data, convert):
         members = enums[data['enum_id']]
